from IPython.core.interactiveshell import InteractiveShell


def show_all_output():
    """
    Display the output of all expressions in a Jupyter notebook cell.

    This function sets the `ast_node_interactivity` attribute of the `InteractiveShell`
    to "all", causing all expressions in a cell to be executed and their outputs displayed.

    Example:
        >>> show_all_output()
        >>> x = 10
        >>> y = 20
        >>> x + y
        30
        >>> x * y
        200
    """
    InteractiveShell.ast_node_interactivity = "all"


def show_last_output():
    """
    Display only the output of the last expression in a Jupyter notebook cell.

    This function sets the `ast_node_interactivity` attribute of the `InteractiveShell`
    to "last", causing only the last expression in a cell to be executed and its output displayed.

    Example:
        >>> show_last_output()
        >>> a = [1, 2, 3]
        >>> b = [4, 5, 6]
        >>> a
        >>> b
        >>> a + b
        [1, 2, 3, 4, 5, 6]
    """
    InteractiveShell.ast_node_interactivity = "last"



import numpy as np
import pandas as pd
import seaborn as sns
from matplotlib import pyplot as plt
from sklearn.metrics import confusion_matrix as _confusion_matrix


def confusion_matrix(
    y_true: np.ndarray,
    y_pred: np.ndarray,
    ignore_diagonal: bool = True,
) -> np.ndarray:
    cm = _confusion_matrix(y_true, y_pred)
    cm = cm.astype("float")
    if ignore_diagonal:
        for i in range(cm.shape[0]):
            cm[i][i] = np.nan
    return cm


def plot_confusion_matrix(confusion_matrix: np.ndarray) -> None:
    size = confusion_matrix.shape[0]
    df_cm = pd.DataFrame(
        confusion_matrix,
        index=list(range(size)),
        columns=list(range(size)),
    )

    sns.heatmap(df_cm, annot=True, fmt="0.0f")
    plt.xlabel("Predicted Class", fontsize=14)
    plt.ylabel("Actual Class", fontsize=14)
    plt.title("Confusion Matrix", fontsize=16)
